@@ -14,13 +14,13 @@
 #:#  Contact us for information about our services: info@rpact.com
 #:#  
 #:#  File name: test-f_analysis_input_validation.R
-#:#  Creation date: 05 September 2020, 14:25:43
-#:#  File version: $Revision: 3596 $
-#:#  Last changed: $Date: 2020-09-07 08:04:48 +0200 (Mo, 07 Sep 2020) $
+#:#  Creation date: 18 May 2021, 17:44:19
+#:#  File version: $Revision: 4888 $
+#:#  Last changed: $Date: 2021-05-19 14:08:44 +0200 (Mi, 19 Mai 2021) $
 #:#  Last changed by: $Author: pahlke $
 #:#  
 
-context("Testing the correct input validation of all analysis functions")
+context("Testing the Correct Input Validation of All Analysis Functions")
 
 
 test_that("Errors and warnings for calculation of analysis results with dataset of means", {
@@ -74,15 +74,14 @@ test_that("Errors and warnings for calculation of analysis results with dataset
 	expect_error(getAnalysisResults(design = design3, dataInput = dataExample4,
 		intersectionTest = "Dunnett", varianceOption = "pairwisePooled"),
 		paste0("Illegal argument: variance option ('pairwisePooled') must be 'overallPooled' ",
-			"because conditional Dunnett test was specified as design"), fixed = TRUE)
+		"because conditional Dunnett test was specified as design"), fixed = TRUE)
 
-	expect_warning(getAnalysisResults(design = design1, dataInput = dataExample4,
+	expect_error(getAnalysisResults(design = design1, dataInput = dataExample4,
 		intersectionTest = "Dunnett", varianceOption = "pairwisePooled", nPlanned = c(20, 20)),
 		"Dunnett t test can only be performed with overall variance estimation", fixed = TRUE)
 
-	expect_warning(getConditionalPower(getStageResults(design1, dataInput = dataExample1), 
-		nPlanned = c(20, 20), allocationRatioPlanned = 1.2))
 	expect_error(getConditionalPower(getStageResults(design1, dataInput = dataExample2), 
 		nPlanned = c(20, 20), allocationRatioPlanned = -1))
+
 })
 
